#!/usr/bin/python
# -*- coding: utf-8 -*-
import os
from config import *

class DeviceManager:
	_instance = None

	def __new__(cls, *args, **kwargs):
		if not cls._instance:  
			cls._instance = super(Singleton, cls).__new__(cls, *args, **kwargs)  
		return cls._instance

	def getDeviceTypeByAppName(self, appName):
		return "iphoneos"